## 3.3.4.1 (2023-01-07)

Use `pyasn1` in `python-jose` (#9469)

## 3.3.4 (2022-07-15)

python-jose: improvements to jose.backends (#8294)

## 3.3.3 (2022-07-13)

Complete python-jose typing (#8258)

## 3.3.2 (2022-07-06)

Improve python-jose jws and jwt modules (#8238)

Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>
Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

## 3.3.1 (2022-05-26)

Third-party stubs: fix several fictitious type aliases (#7958)

## 3.3.0 (2022-04-12)

Add stubs for Python-Jose (#7613)

